==> jc-1.4.0.tar.gz: soot/javaToJimple/jj/ast/JjFieldDecl__5fc.h <==
// public class soot.javaToJimple.jj.ast.JjFieldDecl_c

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3dfad60ca560f387 polyglot_ext_jl_ast_FieldDecl__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd10a20e5b60595 soot_javaToJimple_jj_ast_JjFieldDecl__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_FieldDecl__5fc

#include "polyglot/ext/jl/ast/FieldDecl__5fc.h"

#ifndef _JC_soot_javaToJimple_jj_ast_JjFieldDecl__5fc_H_
#define _JC_soot_javaToJimple_jj_ast_JjFieldDecl__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_TypeNode$object;
struct _jc_polyglot_types_Flags$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_AscriptionVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object;

typedef const struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable;
typedef const struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$method$_init$f58f8feaa80a8242(_jc_env *, struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_polyglot_types_Flags$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$method$childExpectedType$83ae3a389d7a41bf(_jc_env *, struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object *, struct _jc_object *, struct _jc_polyglot_visit_AscriptionVisitor$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$method_info$childExpectedType$83ae3a389d7a41bf;

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods {
	struct _jc_object	*(*childExpectedType$83ae3a389d7a41bf)(_jc_env *, struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object *, struct _jc_object *, struct _jc_polyglot_visit_AscriptionVisitor$object *);
};

// Vtable
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_FieldDecl__5fc$vmethods	polyglot_ext_jl_ast_FieldDecl__5fc;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods	soot_javaToJimple_jj_ast_JjFieldDecl__5fc;
};

// Vtype
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs {
    _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs	soot_javaToJimple_jj_ast_JjFieldDecl__5fc;
    _jc_polyglot_ext_jl_ast_FieldDecl__5fc$sub_refs	polyglot_ext_jl_ast_FieldDecl__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_FieldDecl__5fc$sub_nonrefs	polyglot_ext_jl_ast_FieldDecl__5fc;
    _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs	soot_javaToJimple_jj_ast_JjFieldDecl__5fc;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object {
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype	*vtype;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_ast_JjFieldDecl__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$class_object;

#endif	/* _JC_soot_javaToJimple_jj_ast_JjFieldDecl__5fc_H_ */

==> jc-1.4.6.tar.gz: soot/javaToJimple/jj/ast/JjFieldDecl__5fc.h <==
// public class soot.javaToJimple.jj.ast.JjFieldDecl_c

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3dfad60ca560f387 polyglot_ext_jl_ast_FieldDecl__5fc
// @dep_class 687ec145cf1dbf5b polyglot_ext_jl_ast_Node__5fc
// @dep_class 9bd10a20e5b60595 soot_javaToJimple_jj_ast_JjFieldDecl__5fc

// header file dependencies
// @dep_header polyglot_ext_jl_ast_FieldDecl__5fc

#include "polyglot/ext/jl/ast/FieldDecl__5fc.h"

#ifndef _JC_soot_javaToJimple_jj_ast_JjFieldDecl__5fc_H_
#define _JC_soot_javaToJimple_jj_ast_JjFieldDecl__5fc_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_polyglot_ast_Expr$object;
struct _jc_polyglot_ast_TypeNode$object;
struct _jc_polyglot_types_Flags$object;
struct _jc_polyglot_types_Type$object;
struct _jc_polyglot_util_Position$object;
struct _jc_polyglot_visit_AscriptionVisitor$object;

// Typedefs
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs;
typedef struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object;

typedef const struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods;
typedef const struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable;
typedef const struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype;

// Constructors
extern void _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$method$_init$f58f8feaa80a8242(_jc_env *, struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object *, struct _jc_polyglot_util_Position$object *, struct _jc_polyglot_types_Flags$object *, struct _jc_object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$method$childExpectedType$83ae3a389d7a41bf(_jc_env *, struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object *, struct _jc_object *, struct _jc_polyglot_visit_AscriptionVisitor$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$method_info$childExpectedType$83ae3a389d7a41bf;

// Virtual methods structure
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods {
	struct _jc_object	*(*childExpectedType$83ae3a389d7a41bf)(_jc_env *, struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object *, struct _jc_object *, struct _jc_polyglot_visit_AscriptionVisitor$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_ext_jl_ast_Node__5fc$vmethods	polyglot_ext_jl_ast_Node__5fc;
	_jc_polyglot_ext_jl_ast_FieldDecl__5fc$vmethods	polyglot_ext_jl_ast_FieldDecl__5fc;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vmethods	soot_javaToJimple_jj_ast_JjFieldDecl__5fc;
};

// Vtype
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype {
	_jc_type			type;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs {
    _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_refs	soot_javaToJimple_jj_ast_JjFieldDecl__5fc;
    _jc_polyglot_ext_jl_ast_FieldDecl__5fc$sub_refs	polyglot_ext_jl_ast_FieldDecl__5fc;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_refs	polyglot_ext_jl_ast_Node__5fc;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_ext_jl_ast_Node__5fc$sub_nonrefs	polyglot_ext_jl_ast_Node__5fc;
    _jc_polyglot_ext_jl_ast_FieldDecl__5fc$sub_nonrefs	polyglot_ext_jl_ast_FieldDecl__5fc;
    _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$sub_nonrefs	soot_javaToJimple_jj_ast_JjFieldDecl__5fc;
};

// Object instance structure
struct _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$object {
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype	*vtype;
	_jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$vtype _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_javaToJimple_jj_ast_JjFieldDecl__5fc, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_javaToJimple_jj_ast_JjFieldDecl__5fc$class_object;

#endif	/* _JC_soot_javaToJimple_jj_ast_JjFieldDecl__5fc_H_ */
